#! /bin/bash
export PROJECT_HOME="$(pwd)"
alias ph="cd $PROJECT_HOME"
export PYTHONPATH="$PYTHONPATH:$PROJECT_HOME/vs_maml"

OUTPUT_DIR="$PROJECT_HOME/experiment_output"

EXP_NAME='online_variable_shots_info_reg_pose'
# export N_GPUS=$(nvidia-smi -L | wc -l)
export N_GPUS=8
export N_JOBS=24
export MAX_GPU_MEM_FRAC=1.0

mkdir -p $OUTPUT_DIR/$EXP_NAME
cp $BASH_SOURCE $OUTPUT_DIR/$EXP_NAME

export CUDA_VISIBLE_DEVICES=0

python -m vs_maml.pose_maml_online \
    --seed=2 \
    --inner_steps=5 \
    --inner_lr=1e-1 \
    --outer_lr=1e-4 \
    --outer_clip_gradient=10.0 \
    --inner_clip_gradient=10.0 \
    --inner_clip_gradient_norm=True \
    --meta_train_tasks=10 \
    --per_task_batch_size=2 \
    --inner_batch_size='0-1-2-3-4-5-6-7-8-9-10-11-12-13-14-15-16-17-18-19-20' \
    --outer_batch_size=4 \
    --inner_step_likelihood_reg=1.0 \
    --info_reg=1e-1 \
    --info_reg_init_stddev=1e-4 \
    --info_reg_min_stddev=1e-12 \
    --info_reg_max_stddev=1.0 \
    --inner_lr_type='manual_theory_learned_coef' \
    --inner_lr_scaling='exp' \
    --inner_lr_scaling_coef=1.0 \
    --weight_decay=0.001 \
    --n_steps=100000 \
    --test_interval=10 \
    --test_batches=10 \
    --log_interval=10 \
    --print_interval=50 \
    --max_gpu_mem_frac=$MAX_GPU_MEM_FRAC \
    --gpu_mem_growth=True \
    --train_only_on_cur=False \
    --cont_incl_cur=True \
    --pretrain_steps=10000 \
    --task_steps=240 \
    --batch_steps=10 \
    --cur_task=0 \
    --adaptive_advance=False \
    --advance_thresh=3.0 \
    --datasource='cont_pose' \
    --data_file='./pose_data/pose.pkl' \
    --output_dir="$OUTPUT_DIR/$EXP_NAME/"

