#! /bin/bash

OUTPUT_DIR="$PROJECT_HOME/experiment_output"

EXP_NAME='online_variable_shots_miniimagenet'
# export N_GPUS=$(nvidia-smi -L | wc -l)
export N_GPUS=8
export N_JOBS=24
export MAX_GPU_MEM_FRAC=1.0

mkdir -p $OUTPUT_DIR/$EXP_NAME
cp $BASH_SOURCE $OUTPUT_DIR/$EXP_NAME

export CUDA_VISIBLE_DEVICES=0

python -m vs_maml.miniimagenet_maml_online \
    --seed=2 \
    --inner_steps=5 \
    --inner_lr=3e-2 \
    --outer_lr=1e-4 \
    --outer_clip_gradient=10.0 \
    --inner_clip_gradient=0.0 \
    --meta_train_tasks=16 \
    --per_task_batch_size=8 \
    --inner_batch_size='0-2-4-6-8-10-12-14-16-18-20' \
    --outer_batch_size=4 \
    --inner_step_likelihood_reg=1.0 \
    --info_reg=1e-1 \
    --info_reg_init_stddev=1e-4 \
    --info_reg_min_stddev=1e-12 \
    --info_reg_max_stddev=1.0 \
    --inner_lr_type='manual_theory_learned_coef' \
    --inner_lr_scaling='exp' \
    --inner_lr_scaling_coef=1.0 \
    --weight_decay=0.001 \
    --n_steps=1000000 \
    --test_interval=20 \
    --test_batches=16 \
    --log_interval=20 \
    --print_interval=100 \
    --max_gpu_mem_frac=$MAX_GPU_MEM_FRAC \
    --gpu_mem_growth=True \
    --train_only_on_cur=False \
    --cont_incl_cur=True \
    --pretrain_steps=5000 \
    --task_steps=1400 \
    --batch_steps=20 \
    --cur_task=39 \
    --adaptive_advance=True \
    --uncertainty_advance=False \
    --advance_thresh=0.75 \
    --datasource='cont_miniimagenet' \
    --data_file='./miniimagenet.pkl' \
    --output_dir="$OUTPUT_DIR/$EXP_NAME/"
